# Documentation

## rsmime

Rust powered Python package for signing data in S/MIME format

<a href="https://pypi.org/project/rsmime/">![PyPI](https://img.shields.io/pypi/v/rsmime?color=gr&style=for-the-badge)</a>

## API Reference

::: rsmime

::: rsmime.exceptions
